@@ -3,17 +3,13 @@ BEGIN {
   $Hailo::Command::AUTHORITY = 'cpan:AVAR';
 }
 BEGIN {
-  $Hailo::Command::VERSION = '0.50';
+  $Hailo::Command::VERSION = '0.51';
 }
 
 use 5.010;
 use Any::Moose;
 use Any::Moose 'X::Getopt';
-BEGIN {
-    return unless Any::Moose::moose_is_preferred();
-    require MooseX::StrictConstructor;
-    MooseX::StrictConstructor->import;
-}
+use Any::Moose 'X::StrictConstructor';
 use namespace::clean -except => 'meta';
 
 extends 'Hailo';
@@ -22,7 +18,13 @@ with any_moose('X::Getopt::Dashes');
 
 ## Our internal Getopts method that Hailo.pm doesn't care about.
 
-has help => (
+# MooseX::Getopt 81b19ed83c by Karen Etheridge changed the help
+# attribute to help_flag.
+{
+my @go_attrs = any_moose('X::Getopt::GLD')->meta->get_attribute_list;
+my $help_attr = 'help_flag' ~~ @go_attrs ? 'help_flag' : 'help';
+
+has $help_attr => (
     traits        => [ qw/ Getopt / ],
     cmd_aliases   => 'h',
     cmd_flag      => 'help',
@@ -31,6 +33,7 @@ has help => (
     default       => 0,
     documentation => "You're soaking it in",
 );
+}
 
 has _go_version => (
     traits        => [ qw/ Getopt / ],
