@@ -3,17 +3,13 @@ BEGIN {
   $Hailo::Tokenizer::Words::AUTHORITY = 'cpan:AVAR';
 }
 BEGIN {
-  $Hailo::Tokenizer::Words::VERSION = '0.50';
+  $Hailo::Tokenizer::Words::VERSION = '0.51';
 }
 
 use 5.010;
 use utf8;
 use Any::Moose;
-BEGIN {
-    return unless Any::Moose::moose_is_preferred();
-    require MooseX::StrictConstructor;
-    MooseX::StrictConstructor->import;
-}
+use Any::Moose 'X::StrictConstructor';
 use Regexp::Common qw/ URI /;
 use namespace::clean -except => 'meta';
 
